==> spip_4.0.4.orig.tar.xz: plugins-dist/revisions/lang/revisions_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Veire li diferença',

	// D
	'diff_para_ajoute' => 'Paràgrafou ajustat',
	'diff_para_deplace' => 'Paràgrafou desplaçat',
	'diff_para_supprime' => 'Paràgrafou suprimat',
	'diff_texte_ajoute' => 'Tèst ajustat',
	'diff_texte_deplace' => 'Tèst desplaçat',
	'diff_texte_supprime' => 'Tèst suprimat',
	'differences_versions' => 'Diferença tra li versioun N<sup>o</sup>@id_version@ e versioun N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurà la versioun N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguit dei revisioun',
	'info_1_revision' => '1 revisioun',
	'info_aucune_revision' => 'Mìnga revisioun',
	'info_historique' => 'Revisioun :',
	'info_historique_lien' => 'Afichà l’isòrica dei moudificacioun',
	'info_historique_titre' => 'Seguit dei revisioun',
	'info_nb_revisions' => '@nb@ revisioun',

	// L
	'label_choisir_id_version' => 'Seleciounas li versioun da coumparà',
	'label_config_revisions_objets' => 'Soubre de que ouget ativà li revisioun :',

	// M
	'message_valider_recuperer_version' => 'Validà lou fourmulari da tournà en aquela versioun.',

	// O
	'objet_editorial' => 'ouget',

	// P
	'plugin_update' => 'Messa a jou dóu plugin "Revisioun" en versioun @version@.',

	// T
	'titre_form_revisions_objets' => 'Ativà li revisioun',
	'titre_restaurer_version' => 'Restaurà una versioun',
	'titre_revisions' => 'Revisioun',

	// V
	'version_deplace_rubrique' => 'Desplaçat de <b>« @from@ »</b> fin a <b>« @to@ »</b>.',
	'version_initiale' => 'Versiounb iniciala',
	'voir_differences' => 'Veire li diferença',
	'voir_mes_revisions' => 'Li miéu revisioun',
	'voir_revisions' => 'Veire li revisioun (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Touti li revisioun'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Veire li diferença',

	// D
	'diff_para_ajoute' => 'Paràgrafou ajustat',
	'diff_para_deplace' => 'Paràgrafou desplaçat',
	'diff_para_supprime' => 'Paràgrafou suprimat',
	'diff_texte_ajoute' => 'Tèst ajustat',
	'diff_texte_deplace' => 'Tèst desplaçat',
	'diff_texte_supprime' => 'Tèst suprimat',
	'differences_versions' => 'Diferença tra li versioun N<sup>o</sup>@id_version@ e versioun N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurà la versioun N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguit dei revisioun',
	'info_1_revision' => '1 revisioun',
	'info_aucune_revision' => 'Mìnga revisioun',
	'info_historique' => 'Revisioun :',
	'info_historique_lien' => 'Afichà l’isòrica dei moudificacioun',
	'info_historique_titre' => 'Seguit dei revisioun',
	'info_nb_revisions' => '@nb@ revisioun',

	// L
	'label_choisir_id_version' => 'Seleciounas li versioun da coumparà',
	'label_config_revisions_objets' => 'Soubre de que ouget ativà li revisioun :',

	// M
	'message_valider_recuperer_version' => 'Validà lou fourmulari da tournà en aquela versioun.',

	// O
	'objet_editorial' => 'ouget',

	// P
	'plugin_update' => 'Messa a jou dóu plugin "Revisioun" en versioun @version@.',

	// T
	'titre_form_revisions_objets' => 'Ativà li revisioun',
	'titre_restaurer_version' => 'Restaurà una versioun',
	'titre_revisions' => 'Revisioun',

	// V
	'version_deplace_rubrique' => 'Desplaçat de <b>« @from@ »</b> fin a <b>« @to@ »</b>.',
	'version_initiale' => 'Versiounb iniciala',
	'voir_differences' => 'Veire li diferença',
	'voir_mes_revisions' => 'Li miéu revisioun',
	'voir_revisions' => 'Veire li revisioun (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Touti li revisioun',
];
